﻿
# 
#   ______                           __        ____    _      __  __     
#  / ___(_)__ ___ _  ___  ___ ____  / /__     / __/___(_)_ __/ /_/ /____ 
# / (_ / / _ `/  ' \/ _ \/ _ `/ _ \/ / _ \   _\ \/ __/ / // / __/ __/ _ \
# \___/_/\_,_/_/_/_/ .__/\_,_/\___/_/\___/  /___/\__/_/\_,_/\__/\__/\___/
#                 /_/                                                   
# http://www.giampaolo-sciutto.it/

# Name Script : Export_AD_Users_to_CSV.PS1
# Descrizione : 
# 
# Versione    : 1.0
# Requisiti   : Import-Module ActiveDirectory
# Piattaforme Verificate : Windows 2012R2
#
# Modify by Giampaolo Sciutto
# Date Modify: 28/11/2016
#

# Percorso Generazione file .CSV
$path = Split-Path -parent "C:\script\*.*"
# Variabile data per file log
$LogDate = get-date -f yyyyMMddhhmm
# Definisce il nome del file .CSV che viene generato nella variabile $path
$csvfile = $path + "\ALLADUsers_$logDate.csv"
#importa moduli ActiveDirectory Module
Import-Module ActiveDirectory
# Definisce la OU (modificare)
$SearchBase = "DC=gs,DC=local"
# Richiede inserimento credenziali dominio
$GetAdminact = Get-Credential
# Definisce il server dove raccoglie informazioni (Modificare)
$ADServer = 'DC01'

$AllADUsers = Get-ADUser -server $ADServer `
-Credential $GetAdminact -searchbase $SearchBase `
-Filter * -Properties * | Where-Object {$_.info -NE 'Migrated'} #ensures that updated users are never exported.

$AllADUsers |
Select-Object @{Label = "First Name";Expression = {$_.GivenName}},
@{Label = "Last Name";Expression = {$_.Surname}},
@{Label = "Display Name";Expression = {$_.DisplayName}},
@{Label = "Logon Name";Expression = {$_.sAMAccountName}},
@{Label = "Full address";Expression = {$_.StreetAddress}},
@{Label = "City";Expression = {$_.City}},
@{Label = "State";Expression = {$_.st}},
@{Label = "Post Code";Expression = {$_.PostalCode}},
@{Label = "Country/Region";Expression = {if (($_.Country -eq 'GB')  ) {'United Kingdom'} Else {''}}},
@{Label = "Job Title";Expression = {$_.Title}},
@{Label = "Company";Expression = {$_.Company}},
@{Label = "Directorate";Expression = {$_.Description}},
@{Label = "Department";Expression = {$_.Department}},
@{Label = "Office";Expression = {$_.OfficeName}},
@{Label = "Phone";Expression = {$_.telephoneNumber}},
@{Label = "Email";Expression = {$_.Mail}},
@{Label = "Manager";Expression = {%{(Get-AdUser $_.Manager -server $ADServer -Properties DisplayName).DisplayName}}},
@{Label = "Account Status";Expression = {if (($_.Enabled -eq 'TRUE')  ) {'Enabled'} Else {'Disabled'}}}, # the 'if statement# replaces $_.Enabled
@{Label = "Last LogOn Date";Expression = {$_.lastlogondate}} | 

#Export CSV
Export-Csv -Path $csvfile -NoTypeInformation
